@@ -40,12 +40,12 @@
 
 #include <kpushbutton.h>
 #include <kcombobox.h>
-#include <klistview.h>
-#include <kapplication.h>
+#include <tdelistview.h>
+#include <tdeapplication.h>
 #include <kiconloader.h>
-#include <kmessagebox.h>
-#include <kpopupmenu.h>
-#include <klocale.h>
+#include <tdemessagebox.h>
+#include <tdepopupmenu.h>
+#include <tdelocale.h>
 #include <kstandarddirs.h>
 
 WirelessAssistant::WirelessAssistant(TQWidget* parent, const char* name, bool modal, WFlags fl)
@@ -54,7 +54,7 @@ WirelessAssistant::WirelessAssistant(TQWidget* parent, const char* name, bool mo
         buttonScan->setIconSet( SmallIconSet("reload") );
         buttonConnect->setIconSet( SmallIconSet("connect_creating") );
         buttonOptions->setIconSet( SmallIconSet("configure") );
-        buttonClose->setIconSet( SmallIconSet("fileclose") );
+        buttonClose->setIconSet( SmallIconSet("window-close") );
 
         netList->setAllColumnsShowFocus(1);
         netList->setItemMargin(8);
@@ -84,7 +84,7 @@ WirelessAssistant::WirelessAssistant(TQWidget* parent, const char* name, bool mo
                  this, TQT_SLOT(enableAllMessages()) );
 
         /// Global KDE Options
-        connect( KApplication::kApplication(), TQT_SIGNAL(settingsChanged(int)),
+        connect( TDEApplication::kApplication(), TQT_SIGNAL(settingsChanged(int)),
                  this, TQT_SLOT(updateConfiguration(int)) );
 
         setMouseBehaviour();
@@ -202,7 +202,7 @@ void WirelessAssistant::init()
                 return;
         }
 
-	KStandardDirs standardDirs;
+	TDEStandardDirs standardDirs;
 	wpaConfigFile = standardDirs.saveLocation("config").append("wlassistantwpa");
 
         ///////////////////////////////////////
@@ -320,7 +320,7 @@ void WirelessAssistant::netScan( const WANetParams & np )
 		if (DelayBeforeScanning>0) {
         		statusLabel->setText(i18n("Waiting before scanning..."));
         		statusLabel->repaint();
-			KApplication::eventLoop()->processEvents( TQEventLoop::ExcludeUserInput );
+			TDEApplication::eventLoop()->processEvents( TQEventLoop::ExcludeUserInput );
 			usleep(DelayBeforeScanning * 1000000); // delay * 1000ms
 		}
         }
@@ -779,7 +779,7 @@ void WirelessAssistant::netDisconnect( const bool & quiet )
                         	TQTimer* tmr = new TQTimer();
                         	tmr->start(1500, true);	//wait 1.5sec for dhcp client to really shutdown, single shot.
                         	while ( tmr->isActive() ) {
-                                	KApplication::eventLoop()->processEvents( TQEventLoop::AllEvents );
+                                	TDEApplication::eventLoop()->processEvents( TQEventLoop::AllEvents );
                                 	usleep(75*1000); //75msec on Linux
                         	}
                         	delete tmr;
@@ -839,7 +839,7 @@ TQListViewItem* WirelessAssistant::getItemByEssid( const TQString & essid )
 
 void WirelessAssistant::updateConfiguration(int category)
 {
-        if (category == KApplication::SETTINGS_MOUSE) {
+        if (category == TDEApplication::SETTINGS_MOUSE) {
                 setMouseBehaviour();
                 return;
         }
@@ -877,7 +877,7 @@ void WirelessAssistant::enableAllMessages()
 
 void WirelessAssistant::setMouseBehaviour()
 {
-        if ( KGlobalSettings::singleClick() ) {
+        if ( TDEGlobalSettings::singleClick() ) {
                 disconnect( netList, TQT_SIGNAL(selectionChanged(TQListViewItem*)),
                             this, TQT_SLOT(updateConnectButton(TQListViewItem*)) );
                 disconnect( netList, TQT_SIGNAL(doubleClicked(TQListViewItem*, const TQPoint &, int)),
@@ -950,12 +950,12 @@ TQString WirelessAssistant::runCommand( const TQStringList & cmd, int timeout, b
         int i = 0;
 
         while ( p->isRunning() ) { // PROCESS USER EVENTS
-                KApplication::eventLoop()->processEvents( TQEventLoop::AllEvents );
+                TDEApplication::eventLoop()->processEvents( TQEventLoop::AllEvents );
                 usleep(75*1000); //75msec on Linux (75000msec on Windows...)
                 if (i==27) { // ca 2sec have passed and the process is still running. Replace the 'Close' button with 'Stop'.
                         disconnect(buttonClose, TQT_SIGNAL(clicked()),
                                    this, TQT_SLOT(close()) );
-                        buttonClose->setIconSet( SmallIconSet("stop") );
+                        buttonClose->setIconSet( SmallIconSet("process-stop") );
                         buttonClose->setText( i18n("&Stop") );
                         TQToolTip::remove
                                 (buttonClose);
@@ -970,7 +970,7 @@ TQString WirelessAssistant::runCommand( const TQStringList & cmd, int timeout, b
         if (i>27) {//set 'stop' back to 'close' if needed
                 connect(buttonClose, TQT_SIGNAL(clicked()),
                         this, TQT_SLOT(close()) );
-                buttonClose->setIconSet( SmallIconSet("fileclose") );
+                buttonClose->setIconSet( SmallIconSet("window-close") );
                 buttonClose->setText( i18n("&Quit") );
                 TQToolTip::remove
                         (buttonClose);
@@ -1006,7 +1006,7 @@ void WirelessAssistant::setUi(int uiState)
                 buttonScan->setEnabled( false );
                 buttonConnect->setEnabled( false );
                 buttonOptions->setEnabled( false );
-                KApplication::setOverrideCursor( TQCursor(TQt::BusyCursor) );
+                TDEApplication::setOverrideCursor( TQCursor(TQt::BusyCursor) );
         } else {
                 if (devCombo->count() > 0) {
                         devCombo->setEnabled( true );
@@ -1015,7 +1015,7 @@ void WirelessAssistant::setUi(int uiState)
                 if (netList->childCount() > 0)
                         buttonConnect->setEnabled( true );
                 buttonOptions->setEnabled( true );
-                KApplication::restoreOverrideCursor();
+                TDEApplication::restoreOverrideCursor();
         }
 }
 
@@ -1030,7 +1030,7 @@ void WirelessAssistant::showItemContextMenu( TQListViewItem* i, const TQPoint& p
 	if (search == "any") search = nvi->essid();
         bool isConfigured = setNetParamsFromConfig(search);
 
-        KPopupMenu *icm = new KPopupMenu();
+        TDEPopupMenu *icm = new TDEPopupMenu();
         icm->insertTitle(nvi->essid());
         if (isConfigured) {
                 if (nvi->isConnected()) {
@@ -1234,7 +1234,7 @@ bool WirelessAssistant::setWpaClientEnabled( bool e, const TQString& iface, TQSt
 	while ( !(o =runCommand( TQStringList(Commands.wpa_cli) << TQString("-i%1").arg(NetParams.iface) << "status" )).contains("Failed to connect") ) {
 		for (int c = 0; c < 15; c++) {
 			usleep(75*1000); //75msec
-			KApplication::eventLoop()->processEvents( TQEventLoop::AllEvents );
+			TDEApplication::eventLoop()->processEvents( TQEventLoop::AllEvents );
 			i++;
 		}
 		if (i>400) { //more than 30sec have passed
